---
title: FinnGen Meta Analysis
---

[FinnGen Meta Analysis](https://mvp-ukbb.finngen.fi/about) is a meta analysis that combines genetic data from three major biobanks: FinnGen, UK Biobank (UKBB), and the Million Veteran Program (MVP).
